use bevy::{prelude::*, render::view::RenderLayers};

#[derive(Resource, Debug, Clone)]
pub struct GlobalState {
    pub cursor_position: Vec2,
    pub window_extent: Vec2,
    pub polygon_started: bool,
    pub view_2d: bool,
    pub extrusion_height: f32,

    pub offscreen_image: Handle<Image>,
    pub offscreen_image_size: Vec2,
    pub offscreen_render_layer: RenderLayers,

    pub camera_3d: Entity,
    pub camera_2d: Entity,
}

impl GlobalState {
    pub fn new(
        camera_2d: Entity,
        camera_3d: Entity,
        offscreen_image: Handle<Image>,
        offscreen_image_size: Vec2,
        offscreen_render_layer: RenderLayers,
    ) -> Self {
        Self {
            cursor_position: Vec2::default(),
            window_extent: Vec2::default(),
            polygon_started: false,
            view_2d: true,
            extrusion_height: 20.0,

            offscreen_image,
            offscreen_image_size,
            offscreen_render_layer,

            camera_3d,
            camera_2d,
        }
    }
}
